@@ -8,7 +8,7 @@ BEGIN {
     # All engines should subclass the core Regexp package
     our @ISA = qw( Regexp );
 
-    our $VERSION = '0.13';
+    our $VERSION = '0.14';
     XSLoader::load __PACKAGE__, $VERSION;
 }
 
@@ -41,10 +41,10 @@ re::engine::Lua - Lua regular expression engine
 
 =head1 DESCRIPTION
 
-Replaces perl's regex engine in a given lexical scope with the Lua 5.2 one.
+Replaces perl's regex engine in a given lexical scope with the Lua 5.3 one.
 
-See "Lua 5.2 Reference Manual", section 6.4.1 "Patterns",
-L<http://www.lua.org/manual/5.2/manual.html#6.4.1>.
+See "Lua 5.3 Reference Manual", section 6.4.1 "Patterns",
+L<http://www.lua.org/manual/5.3/manual.html#6.4.1>.
 
 =head2 Character Class:
 
@@ -55,7 +55,7 @@ combinations are allowed in describing a character class:
 
 =item B<x>
 
-(where I<x> is not one of the I<magic characters> C<^$()%.[]*+-?)> represents
+(where I<x> is not one of the I<magic characters> C<^$()%.[]*+-?>) represents
 the character I<x> itself.
 
 =item B<.>
@@ -232,12 +232,12 @@ The development is hosted at L<https://github.com/fperrad/re-engine-lua>.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2007-2013 FranE<ccedil>ois PERRAD.
+Copyright 2007-2015 FranE<ccedil>ois PERRAD.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Lua.
 
-The code fragment from original Lua 5.2.2 is under a MIT license,
+The code fragment from original Lua 5.3.0 is under a MIT license,
 see L<http://www.lua.org/license.html>.
 
 =cut
